@@ -5,12 +5,6 @@
 #include <rng/RNG.h>
 #include <JRmath.h>
 
-using std::vector;
-using std::log;
-using std::exp;
-using std::fabs;
-
-
 // define parameters
 // df = par[0]
 // ncp = par[1]
@@ -22,65 +16,61 @@ using std::fabs;
 
 
 namespace jags {
-namespace RoBMA { 
+namespace RoBMA {
 
 DWT1::DWT1() : VectorDist("dwt_1s", 4) {}
 
 
-bool DWT1::checkParameterLength(vector<unsigned int> const &len) const
+bool DWT1::checkParameterLength(std::vector<unsigned int> const &len) const
 {
   // there is one less cut-point then weights
   return n_crit_t(len) == n_omega(len) - 1;
 }
 
-bool DWT1::checkParameterValue(vector<double const *> const &par,
-			    vector<unsigned int> const &len) const
+bool DWT1::checkParameterValue(std::vector<double const *> const &par,
+			    std::vector<unsigned int> const &len) const
 {
   bool omega_OK  = true;
-  bool df_OK;
 
   // all omegas are within [0, 1]
   for(unsigned j = 0; j < (n_omega(len)-1); ++j){
     omega_OK = omega_OK && ( omega(par)[j] >= 0.0 ) && ( omega(par)[j] <= 1.0 );
   }
-  
+
   // df are positive
-  df_OK = *par[0] > 0.0;
+  bool df_OK = *par[0] > 0.0;
 
   return omega_OK && df_OK;
 }
 
 double DWT1::logDensity(double const *x, unsigned int length, PDFType type,
-			  vector<double const *> const &par,
-			  vector<unsigned int> const &len,
+			  std::vector<double const *> const &par,
+			  std::vector<unsigned int> const &len,
 			  double const *lower, double const *upper) const
 {
   double df    = *par[0];
   double ncp   = *par[1];
 
-  double w;
-  double nom;
   double denom = 0;
-  double denom_sum;
-  vector<double> denoms;
-  double log_lik;
+  double w = -68;
+  std::vector<double> denoms;
 
   // select weight to correspond to the current cut-off
   if(*x >= crit_t(par)[n_crit_t(len)-1]){
-    w = log(omega(par)[n_omega(len)-1]);
+    w = std::log(omega(par)[n_omega(len)-1]);
   }else if(*x < crit_t(par)[0]){
-    w = log(omega(par)[0]);
+    w = std::log(omega(par)[0]);
   }else{
     for(unsigned i = 1; i < n_omega(len); ++i){
       if( (*x < crit_t(par)[i] ) && (*x >= crit_t(par)[i-1]) ){
-        w = log(omega(par)[i]);
+        w = std::log(omega(par)[i]);
         break;
       }
     }
   }
 
   // compute the nominator
-  nom = dnt(*x, df, ncp, true) + w;
+  double nom = dnt(*x, df, ncp, true) + w;
 
   // compute the probabilities between cutpoints
   // the first one
@@ -88,7 +78,7 @@ double DWT1::logDensity(double const *x, unsigned int length, PDFType type,
   if(denoms[0] < 0.0){ // check and correct for possibly negative numbers due to numerical imprecission
     denoms[0] = 0.0;
   }
-  denom_sum = denoms[0];
+  double denom_sum = denoms[0];
   // the ones in the middle
   if(n_omega(len) > 1){
     for(unsigned j = 1; j < n_omega(len) - 1; ++j){
@@ -107,18 +97,18 @@ double DWT1::logDensity(double const *x, unsigned int length, PDFType type,
 
   // weight and sum the denominators
   for(unsigned k = 0; k < n_omega(len); ++k){
-    denom = denom + exp(log(denoms[k]) + log(omega(par)[k]));
+    denom = denom + std::exp(std::log(denoms[k]) + std::log(omega(par)[k]));
   }
 
   // compute the log likelihood
-  log_lik = nom-log(denom);
+  double log_lik = nom-std::log(denom);
 
   return log_lik;
 }
 
 void DWT1::randomSample(double *x, unsigned int length,
-			  vector<double const *> const &par,
-			  vector<unsigned int> const &len,
+			  std::vector<double const *> const &par,
+			  std::vector<unsigned int> const &len,
 			  double const *lower, double const *upper,
 			  RNG *rng) const
 {
@@ -126,8 +116,8 @@ void DWT1::randomSample(double *x, unsigned int length,
 }
 
 void DWT1::support(double *lower, double *upper, unsigned int length,
-	     vector<double const *> const &par,
-	     vector<unsigned int> const &len) const
+	     std::vector<double const *> const &par,
+	     std::vector<unsigned int> const &len) const
 {
   // no idea whether this is correct
   for (unsigned int i = 0; i < length; ++i) {
@@ -136,7 +126,7 @@ void DWT1::support(double *lower, double *upper, unsigned int length,
   }
 }
 
-unsigned int DWT1::length(vector<unsigned int> const &len) const
+unsigned int DWT1::length(std::vector<unsigned int> const &len) const
 {
   // no idea how this works
   return 1;
@@ -144,15 +134,15 @@ unsigned int DWT1::length(vector<unsigned int> const &len) const
 
 
 void DWT1::typicalValue(double *x, unsigned int length,
-			  vector<double const *> const &par,
-			  vector<unsigned int> const &len,
+			  std::vector<double const *> const &par,
+			  std::vector<unsigned int> const &len,
 			  double const *lower, double const *upper) const
 {
   // not implemented
 }
 
 
-bool DWT1::isSupportFixed(vector<bool> const &fixmask) const
+bool DWT1::isSupportFixed(std::vector<bool> const &fixmask) const
 {
   return true;
 }
